Hoss python agent
=============================

This is Python agent for Hoss. Hoss tracks and manages 3rd party API. It lets developers quickly add best practices
in integrating with 3rd party API, for example: logging, alerting, auto retry, request queuing and more

Sign up at https://hoss.com for a free account

Install
---------------------------
hoss is available on PyPI and thus can be installed with pip on most platforms.::

$ pip install hoss

Documentation
----------------

See the documentation at https://docs.hoss.com/docs/python-agent
